**PRE PRE ALPHA, still in active development**


Trionyx
=======

Trionyx is an application framework for managing data and processes, or can be used as an glorified customer admin panel for Django.

This package contains the backend for Trionyx. Trionyx backend exposes only an API that is used by the frontend.

Installation
============
To install Trionyx, run:

    pip install Trionyx

Create new project
==================
For creating a new project, run:

    trionyx create_project new_project
